'''
This is a set of modules for creating GA for txt classification.


1. from TERRA_GA.TXT_Classification_GA import TXT_create_Conv_Net

IMG_create_Conv_Net()

2. from TERRA_GA.TXT_Classification_GA import visualize_mean_accuracy

visualize_mean_accuracy(mean_val, max_val)

3. from TERRA_GA.TXT_Classification_GA import Recovery_Conv_Net

Recovery_Conv_Net()

4. from TERRA_GA.TXT_Classification_GA import show_info

show_info()

'''